# Perseus GetEnv Python Library

Majormode Perseus GetEnv Python Library is a helper library to read environment variables.

This library relies on [`python-dotenv`](https://github.com/theskumar/python-dotenv) to read key-value pairs from a `.env` file, which helps in the development of applications following the [12-factor principles](https://12factor.net/).

This library provides a helper function to convert the value of environment variables in the expected data type.

## Installation

To install [Perseus GetEnv Python Library](https://github.com/dcaune/perseus-getenv-python-library), simply enter the follow command line:

``` shell
pip install perseus-getenv-library
```
